@@ -21,7 +21,6 @@
 #include <qdict.h>
 
 namespace Tellico {
-  class FilterItem;
 
 /**
  * @author Robby Stephenson
@@ -41,6 +40,10 @@ public:
   virtual void modifyEntries(Data::EntryVec entries);
   virtual void removeEntries(Data::EntryVec entries);
 
+  virtual void addField(Data::CollPtr, Data::FieldPtr);
+  virtual void modifyField(Data::CollPtr, Data::FieldPtr, Data::FieldPtr);
+  virtual void removeField(Data::CollPtr, Data::FieldPtr);
+
   virtual void    addFilter(FilterPtr filter);
   virtual void modifyFilter(FilterPtr) {}
   virtual void removeFilter(FilterPtr filter);
@@ -69,6 +72,7 @@ private slots:
 
 private:
   virtual void setSorting(int column, bool ascending = true);
+  void resetComparisons();
 
   bool m_notSortedYet;
   QDict<FilterItem> m_itemDict;
