@@ -22,7 +22,6 @@
 #include "../tellico_debug.h"
 
 #include <kcombobox.h>
-#include <kglobal.h> // for KMAX
 #include <kapplication.h>
 #include <kstringhandler.h>
 
@@ -61,7 +60,7 @@ Tellico::Data::CollPtr AlexandriaImporter::collection() {
   dataDir.setNameFilter(QString::fromLatin1("*.yaml"));
   const QStringList files = dataDir.entryList();
   const uint numFiles = files.count();
-  const uint stepSize = KMAX(s_stepSize, numFiles/100);
+  const uint stepSize = QMAX(s_stepSize, numFiles/100);
   const bool showProgress = options() & ImportProgress;
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, progressLabel(), true);
