@@ -36,11 +36,14 @@ signals:
   void signalISBN();
 
 private:
-  State decodeCat(QString& str) const;
-
   bool m_checkISBN : 1;
   mutable bool m_isbn : 1;
 };
 
+class CueCat {
+public:
+  static QValidator::State decode(QString& str);
+};
+
 } // end namespace
 #endif
